package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ResetAppSecretDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppDto;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppVo;
import com.nokia.dingtalk_api.service.AppService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Tag(name = "app", description = "应用管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/app")
public class AppController {
    private final AppService appService;

    @Operation(summary = "查询应用列表")
    @PostMapping("/listApp")
    public R<PageVo<ListAppVo>> listApp(@Valid @RequestBody ListAppDto dto) {
        return appService.listApp(dto);
    }

    @Operation(summary = "添加应用")
    @PostMapping("/addApp")
    public R<Object> addApp(@Valid @RequestBody AddAppDto dto) {
        return appService.addApp(dto);
    }

    @Operation(summary = "更新应用")
    @PostMapping("/updateApp")
    public R<Object> updateApp(@Valid @RequestBody UpdateAppDto dto) {
        return appService.updateApp(dto);
    }

    @Operation(summary = "重置应用密钥")
    @PostMapping("/resetAppSecret")
    public R<Object> resetAppSecret(@Valid @RequestBody ResetAppSecretDto dto) {
        return appService.resetAppSecret(dto);
    }

    @Operation(summary = "删除应用")
    @PostMapping("/deleteApp")
    public R<Object> deleteApp(@Valid @RequestBody DeleteAppDto dto) {
        return appService.deleteApp(dto);
    }
}
