package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppRobotCommandVo;
import com.nokia.dingtalk_api.service.AppRobotCommandService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Tag(name = "appRobotCommand", description = "应用机器人命令管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/appRobotCommand")
public class AppRobotCommandController {
    private final AppRobotCommandService appRobotCommandService;

    @Operation(summary = "查询应用机器人命令列表")
    @PostMapping("/listAppRobotCommand")
    public R<PageVo<ListAppRobotCommandVo>> listAppRobotCommand(@Valid @RequestBody ListAppRobotCommandDto dto) {
        return appRobotCommandService.listAppRobotCommand(dto);
    }

    @Operation(summary = "添加应用机器人命令")
    @PostMapping("/addAppRobotCommand")
    public R<Object> addAppRobotCommand(@Valid @RequestBody AddAppRobotCommandDto dto) {
        return appRobotCommandService.addAppRobotCommand(dto);
    }

    @Operation(summary = "更新应用机器人命令")
    @PostMapping("/updateAppRobotCommand")
    public R<Object> updateAppRobotCommand(@Valid @RequestBody UpdateAppRobotCommandDto dto) {
        return appRobotCommandService.updateAppRobotCommand(dto);
    }

    @Operation(summary = "删除应用机器人命令")
    @PostMapping("/deleteAppRobotCommand")
    public R<Object> deleteAppRobotCommand(@Valid @RequestBody DeleteAppRobotCommandDto dto) {
        return appRobotCommandService.deleteAppRobotCommand(dto);
    }
}
