package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.GetAppRobotOptionsDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAvailableRobotDto;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.GetAppRobotOptionsVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppRobotVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAvailableRobotVo;
import com.nokia.dingtalk_api.service.AppRobotService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Tag(name = "appRobot", description = "应用机器人管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/appRobot")
public class AppRobotController {
    private final AppRobotService appRobotService;

    @Operation(summary = "查询应用机器人列表")
    @PostMapping("/listAppRobot")
    public R<PageVo<ListAppRobotVo>> listAppRobot(@Valid @RequestBody ListAppRobotDto dto) {
        return appRobotService.listAppRobot(dto);
    }

    @Operation(summary = "查询可添加的机器人列表")
    @PostMapping("/listAvailableRobot")
    public R<PageVo<ListAvailableRobotVo>> listAvailableRobot(@Valid @RequestBody ListAvailableRobotDto dto) {
        return appRobotService.listAvailableRobot(dto);
    }

    @Operation(summary = "添加应用机器人")
    @PostMapping("/addAppRobot")
    public R<Object> addAppRobot(@Valid @RequestBody AddAppRobotDto dto) {
        return appRobotService.addAppRobot(dto);
    }

    @Operation(summary = "删除应用机器人")
    @PostMapping("/deleteAppRobot")
    public R<Object> deleteAppRobot(@Valid @RequestBody DeleteAppRobotDto dto) {
        return appRobotService.deleteAppRobot(dto);
    }

    @Operation(summary = "查询应用机器人选项")
    @PostMapping("/getAppRobotOptions")
    public R<List<GetAppRobotOptionsVo>> getAppRobotOptions(@Valid @RequestBody GetAppRobotOptionsDto dto) {
        return appRobotService.getAppRobotOptions(dto);
    }
}
