package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppSftpDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppSftpDto;
import com.nokia.dingtalk_api.pojos.dto.cms.GetAppSftpOptionsDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppSftpDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppSftpDto;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.GetAppSftpOptionsVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppSftpVo;
import com.nokia.dingtalk_api.service.AppSftpService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Tag(name = "appSftp", description = "应用sftp管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/appSftp")
public class AppSftpController {
    private final AppSftpService appSftpService;

    @Operation(summary = "查询应用sftp列表")
    @PostMapping("/listAppSftp")
    public R<PageVo<ListAppSftpVo>> listAppSftp(@Valid @RequestBody ListAppSftpDto dto) {
        return appSftpService.listAppSftp(dto);
    }

    @Operation(summary = "添加应用sftp")
    @PostMapping("/addAppSftp")
    public R<Object> addAppSftp(@Valid @RequestBody AddAppSftpDto dto) {
        return appSftpService.addAppSftp(dto);
    }

    @Operation(summary = "更新应用sftp")
    @PostMapping("/updateAppSftp")
    public R<Object> updateAppSftp(@Valid @RequestBody UpdateAppSftpDto dto) {
        return appSftpService.updateAppSftp(dto);
    }

    @Operation(summary = "删除应用sftp")
    @PostMapping("/deleteAppSftp")
    public R<Object> deleteAppSftp(@Valid @RequestBody DeleteAppSftpDto dto) {
        return appSftpService.deleteAppSftp(dto);
    }

    @Operation(summary = "查询应用sftp选项")
    @PostMapping("/getAppSftpOptions")
    public R<List<GetAppSftpOptionsVo>> getAppSftpOptions(@Valid @RequestBody GetAppSftpOptionsDto dto) {
        return appSftpService.getAppSftpOptions(dto);
    }
}
