package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.EnableAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppTaskLogDto;
import com.nokia.dingtalk_api.pojos.dto.cms.RunAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.StopAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppTaskDto;
import com.nokia.dingtalk_api.pojos.po.AppTaskLogPo;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppTaskVo;
import com.nokia.dingtalk_api.service.AppTaskService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Tag(name = "appTask", description = "应用任务管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/appTask")
public class AppTaskController {
    private final AppTaskService appTaskService;

    @Operation(summary = "查询应用任务列表")
    @PostMapping("/listAppTask")
    public R<PageVo<ListAppTaskVo>> listAppTask(@Valid @RequestBody ListAppTaskDto dto) {
        return appTaskService.listAppTask(dto);
    }

    @Operation(summary = "添加应用任务")
    @PostMapping("/addAppTask")
    public R<Object> addAppTask(@Valid @RequestBody AddAppTaskDto dto) {
        return appTaskService.addAppTask(dto);
    }

    @Operation(summary = "更新应用任务")
    @PostMapping("/updateAppTask")
    public R<Object> updateAppTask(@Valid @RequestBody UpdateAppTaskDto dto) {
        return appTaskService.updateAppTask(dto);
    }

    @Operation(summary = "启用应用任务")
    @PostMapping("/enableAppTask")
    public R<Object> enableAppTask(@Valid @RequestBody EnableAppTaskDto dto) {
        return appTaskService.enableAppTask(dto);
    }

    @Operation(summary = "停止应用任务")
    @PostMapping("/stopAppTask")
    public R<Object> stopAppTask(@Valid @RequestBody StopAppTaskDto dto) {
        return appTaskService.stopAppTask(dto);
    }

    @Operation(summary = "删除应用任务")
    @PostMapping("/deleteAppTask")
    public R<Object> deleteAppTask(@Valid @RequestBody DeleteAppTaskDto dto) {
        return appTaskService.deleteAppTask(dto);
    }

    @Operation(summary = "执行应用任务")
    @PostMapping("/runAppTask")
    public R<Object> runAppTask(@Valid @RequestBody RunAppTaskDto dto) {
        return appTaskService.runAppTask(dto);
    }

    @Operation(summary = "查询应用任务日志列表")
    @PostMapping("/listAppTaskLog")
    public R<PageVo<AppTaskLogPo>> listAppTaskLog(@Valid @RequestBody ListAppTaskLogDto dto) {
        return appTaskService.listAppTaskLog(dto);
    }
}
