package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.annotation.RequiredHeader;
import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.open.BatchRecallOtoMessagesDto;
import com.nokia.dingtalk_api.pojos.dto.open.BatchSendOtoSampleFileDto;
import com.nokia.dingtalk_api.pojos.dto.open.BatchSendOtoSampleImageMsgDto;
import com.nokia.dingtalk_api.pojos.dto.open.BatchSendSampleMarkdownDto;
import com.nokia.dingtalk_api.pojos.dto.open.BatchSendSampleTextDto;
import com.nokia.dingtalk_api.pojos.dto.open.GetUserIdByMobileDto;
import com.nokia.dingtalk_api.pojos.dto.open.GroupSendSampleFileDto;
import com.nokia.dingtalk_api.pojos.dto.open.GroupSendSampleImageMsgDto;
import com.nokia.dingtalk_api.pojos.dto.open.GroupSendSampleMarkdownDto;
import com.nokia.dingtalk_api.pojos.dto.open.GroupSendSampleTextDto;
import com.nokia.dingtalk_api.pojos.dto.open.RecallGroupMessagesDto;
import com.nokia.dingtalk_api.pojos.dto.open.SftpBatchSendOtoSampleFileDto;
import com.nokia.dingtalk_api.pojos.dto.open.SftpBatchSendOtoSampleImageMsgDto;
import com.nokia.dingtalk_api.pojos.dto.open.SftpGroupSendSampleFileDto;
import com.nokia.dingtalk_api.pojos.dto.open.SftpGroupSendSampleImageMsgDto;
import com.nokia.dingtalk_api.pojos.vo.open.BatchRecallOtoMessagesVo;
import com.nokia.dingtalk_api.pojos.vo.open.BatchSendVo;
import com.nokia.dingtalk_api.pojos.vo.open.GetUserIdByMobileVo;
import com.nokia.dingtalk_api.pojos.vo.open.GroupSendVo;
import com.nokia.dingtalk_api.pojos.vo.open.RecallGroupMessagesVo;
import com.nokia.dingtalk_api.pojos.vo.open.UploadVo;
import com.nokia.dingtalk_api.service.OpenService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotBlank;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

@Tag(name = "open", description = "钉钉机器人接口")
@RequiredHeader
@Validated
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/open")
public class OpenController {
    private final OpenService openService;

    @Operation(summary = "机器人发送群聊文本类型消息")
    @PostMapping(value = "/groupSendSampleText")
    public R<GroupSendVo> groupSendSampleText(@Valid @RequestBody GroupSendSampleTextDto dto) {
        return openService.groupSendSampleText(dto);
    }

    @Operation(summary = "机器人发送群聊Markdown类型消息")
    @PostMapping("/groupSendSampleMarkdown")
    public R<GroupSendVo> groupSendSampleMarkdown(@Valid @RequestBody GroupSendSampleMarkdownDto dto) {
        return openService.groupSendSampleMarkdown(dto);
    }

    @Operation(summary = "机器人发送群聊图片类型消息")
    @PostMapping("/groupSendSampleImageMsg")
    public R<GroupSendVo> groupSendSampleImageMsg(@Valid @RequestBody GroupSendSampleImageMsgDto dto) {
        return openService.groupSendSampleImageMsg(dto);
    }

    @Operation(summary = "机器人发送群聊文件类型消息")
    @PostMapping("/groupSendSampleFile")
    public R<GroupSendVo> groupSendSampleFile(@Valid @RequestBody GroupSendSampleFileDto dto) {
        return openService.groupSendSampleFile(dto);
    }

    @Operation(summary = "机器人批量发送文本类型消息")
    @PostMapping("/batchSendOtoSampleText")
    public R<BatchSendVo> batchSendOtoSampleText(@Valid @RequestBody BatchSendSampleTextDto dto) {
        return openService.batchSendOtoSampleText(dto);
    }

    @Operation(summary = "机器人批量发送Markdown类型消息")
    @PostMapping("/batchSendOtoSampleMarkdown")
    public R<BatchSendVo> batchSendOtoSampleMarkdown(@Valid @RequestBody BatchSendSampleMarkdownDto dto) {
        return openService.batchSendOtoSampleMarkdown(dto);
    }

    @Operation(summary = "机器人批量发送图片类型消息")
    @PostMapping("/batchSendOtoSampleImageMsg")
    public R<BatchSendVo> batchSendOtoSampleImageMsg(@Valid @RequestBody BatchSendOtoSampleImageMsgDto dto) {
        return openService.batchSendOtoSampleImageMsg(dto);
    }

    @Operation(summary = "机器人批量发送文件类型消息")
    @PostMapping("/batchSendOtoSampleFile")
    public R<BatchSendVo> batchSendOtoSampleFile(@Valid @RequestBody BatchSendOtoSampleFileDto dto) {
        return openService.batchSendOtoSampleFile(dto);
    }

    @Operation(summary = "批量撤回人与机器人会话中机器人消息")
    @PostMapping("/batchRecallOtoMessages")
    public R<BatchRecallOtoMessagesVo> batchRecallOtoMessages(@Valid @RequestBody BatchRecallOtoMessagesDto dto) {
        return openService.batchRecallOtoMessages(dto);
    }

    @Operation(summary = "企业机器人撤回内部群消息")
    @PostMapping("/recallGroupMessages")
    public R<RecallGroupMessagesVo> recallGroupMessages(@Valid @RequestBody RecallGroupMessagesDto dto) {
        return openService.recallGroupMessages(dto);
    }

    @Operation(summary = "根据手机号获取用户的userId")
    @PostMapping("/getUserIdByMobile")
    public R<GetUserIdByMobileVo> getUserIdByMobile(@Valid @RequestBody GetUserIdByMobileDto dto) {
        return openService.getUserIdByMobile(dto);
    }

    @Operation(summary = "上传媒体文件")
    @PostMapping("/upload")
    public R<UploadVo> upload(
            @NotBlank(message = "robotCode不能为空") @Parameter(description = "机器人的编码 base64", required = true) String robotCode,
            @Parameter(description = "文件，最大20MB", required = true) @RequestPart("file") MultipartFile file) {
        return openService.upload(robotCode, file);
    }

    @Operation(summary = "机器人通过sftp下载图片并发送群聊图片类型消息")
    @PostMapping("/sftpGroupSendSampleImageMsg")
    public R<GroupSendVo> sftpGroupSendSampleImageMsg(@Valid @RequestBody SftpGroupSendSampleImageMsgDto dto) {
        return openService.sftpGroupSendSampleImageMsg(dto);
    }

    @Operation(summary = "机器人通过sftp下载文件并发送群聊文件类型消息")
    @PostMapping("/sftpGroupSendSampleFile")
    public R<GroupSendVo> sftpGroupSendSampleFile(@Valid @RequestBody SftpGroupSendSampleFileDto dto) {
        return openService.sftpGroupSendSampleFile(dto);
    }

    @Operation(summary = "机器人通过sftp下载图片并批量发送图片类型消息")
    @PostMapping("/sftpBatchSendOtoSampleImageMsg")
    public R<BatchSendVo> sftpBatchSendOtoSampleImageMsg(@Valid @RequestBody SftpBatchSendOtoSampleImageMsgDto dto) {
        return openService.sftpBatchSendOtoSampleImageMsg(dto);
    }

    @Operation(summary = "机器人通过sftp下载文件并批量发送文件类型消息")
    @PostMapping("/sftpBatchSendOtoSampleFile")
    public R<BatchSendVo> sftpBatchSendOtoSampleFile(@Valid @RequestBody SftpBatchSendOtoSampleFileDto dto) {
        return openService.sftpBatchSendOtoSampleFile(dto);
    }
}
