package com.nokia.dingtalk_api.controller;

import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.pojos.dto.cms.AddRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateRobotDto;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.GetRobotOptionsVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListRobotVo;
import com.nokia.dingtalk_api.service.RobotService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Tag(name = "robot", description = "机器人管理")
@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping("/api/robot")
public class RobotController {
    private final RobotService robotService;

    @Operation(summary = "查询机器人列表")
    @PostMapping("/listRobot")
    public R<PageVo<ListRobotVo>> listRobot(@Valid @RequestBody ListRobotDto dto) {
        return robotService.listRobot(dto);
    }

    @Operation(summary = "添加机器人")
    @PostMapping("/addRobot")
    public R<Object> addRobot(@Valid @RequestBody AddRobotDto dto) {
        return robotService.addRobot(dto);
    }

    @Operation(summary = "更新机器人")
    @PostMapping("/updateRobot")
    public R<Object> updateRobot(@Valid @RequestBody UpdateRobotDto dto) {
        return robotService.updateRobot(dto);
    }

    @Operation(summary = "删除机器人")
    @PostMapping("/deleteRobot")
    public R<Object> deleteRobot(@Valid @RequestBody DeleteRobotDto dto) {
        return robotService.deleteRobot(dto);
    }

    @Operation(summary = "查询机器人选项")
    @PostMapping("/getRobotOptions")
    public R<List<GetRobotOptionsVo>> getRobotOptions() {
        return robotService.getRobotOptions();
    }
}
