package com.nokia.dingtalk_api.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppRobotDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAvailableRobotDto;
import com.nokia.dingtalk_api.pojos.po.AppPo;
import com.nokia.dingtalk_api.pojos.po.AppRobotPo;
import com.nokia.dingtalk_api.pojos.po.RobotPo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppRobotVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAvailableRobotVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * <p>
 * 应用机器人关联 Mapper 接口
 * </p>
 *
 */
@Mapper
public interface AppRobotMapper extends BaseMapper<AppRobotPo> {
    /**
     * 查询应用机器人列表
     */
    @Select("""
<script>
with t101 as (
select
    b.robot_code,
    b.robot_name,
    b.robot_secret
from
    dingtalk.app_robot a
join dingtalk.robot b on
    a.robot_code = b.robot_code
where
    a.app_id = #{dto.appId}
    and b.deleted = 0
<if test="dto.robotName != null and dto.robotName != ''">
  and b.robot_name like '%' || #{dto.robotName} || '%'
</if>
<if test="dto.robotCode != null and dto.robotCode != ''">
  and b.robot_code = #{dto.robotCode}
</if>
)
select * from t101
</script>
""")
    List<ListAppRobotVo> listAppRobot(Page<ListAppRobotVo> page, @Param("dto") ListAppRobotDto dto);

    /**
     * 查询应用可添加的机器人
     */
    @Select("""
<script>
select
    *
from
    dingtalk.robot a
where
    a.deleted = 0
    and not exists (
    select
        1
    from
        dingtalk.app_robot b
    where
        a.robot_code = b.robot_code
        and b.app_id = #{dto.appId})
<if test="dto.robotName != null and dto.robotName != ''">
  and robot_name like '%' || #{dto.robotName} || '%'
</if>
<if test="dto.robotCode != null and dto.robotCode != ''">
  and robot_code = #{dto.robotCode}
</if>
</script>
""")
    List<ListAvailableRobotVo> listAvailableRobot(Page<ListAvailableRobotVo> page, ListAvailableRobotDto dto);

    /**
     * 根据appId和robotCode查询机器人
     */
    @Select("""
select
    b.*
from
    dingtalk.app_robot a
join dingtalk.robot b on
    a.robot_code = b.robot_code
where
    b.deleted = 0
    and a.app_id = #{appId}
    and a.robot_code = #{robotCode}
""")
    RobotPo getRobotByAppIdAndRobotCode(@Param("appId") String appId, @Param("robotCode") String robotCode);

    /**
     * 查询机器人关联的应用列表
     */
    @Select("""
select
    *
from
    dingtalk.app a
where
    a.deleted = 0
    and ((exists (
    select
        1
    from
        dingtalk.app_robot b
    where
        b.robot_code = #{robotCode}
        and a.app_id = b.app_id)
    or exists(
    select
        1
    from
        dingtalk.app_task c
    where
        a.app_id = c.app_id
        and (robot_code = #{robotCode}
            or alert_robot_code = #{robotCode})))
    or exists(
    select
        1
    from
        dingtalk.alert_config
    where
        robot_code = #{robotCode}))
order by a.app_name
""")
    List<AppPo> listRobotApp(@Param("robotCode") String robotCode);
}
