package com.nokia.dingtalk_api.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.nokia.dingtalk_api.pojos.bo.AppTaskBo;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppTaskDto;
import com.nokia.dingtalk_api.pojos.po.AppTaskPo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * <p>
 * 应用定时任务 Mapper 接口
 * </p>
 *
 */
@Mapper
public interface AppTaskMapper extends BaseMapper<AppTaskPo> {

    /**
     * 查询运行中的应用任务
     * @param status 任务状态
     */
    @Select("""
select
    a.*,
    b.app_name,
    c.robot_name,
    c.robot_secret,
    d.host,
    d.port,
    d.username,
    d."password",
    f.robot_secret as alert_robot_secret
from
    dingtalk.app_task a
join dingtalk.app b on
    a.app_id = b.app_id
join dingtalk.robot c on
    a.robot_code = c.robot_code
join dingtalk.app_sftp d on
    a.sftp_id = d.sftp_id
    and a.app_id = d.app_id
join dingtalk.app_robot e on
    a.app_id = e.app_id
    and a.robot_code = e.robot_code
left join dingtalk.robot f on
    a.alert_robot_code = f.robot_code
where
    a.cron is not null
    and a.cron != ''
    and b.deleted = 0
    and c.deleted = 0
    and a.status = #{status}
order by a.update_time desc
""")
    List<AppTaskBo> getRunningAppTasks(@Param("status") Integer status);

    /**
     * 查询应用任务
     */
    @Select("""
<script>
with t101 as (
select
    a.*,
    b.app_name,
    c.robot_name,
    d.host,
    d.port,
    d.username,
    d."password",
    f.robot_name as alert_robot_name
from
    dingtalk.app_task a
join dingtalk.app b on
    a.app_id = b.app_id
join dingtalk.robot c on
    a.robot_code = c.robot_code
join dingtalk.app_sftp d on
    a.sftp_id = d.sftp_id
    and a.app_id = d.app_id
join dingtalk.app_robot e on
    a.app_id = e.app_id
    and a.robot_code = e.robot_code
left join dingtalk.robot f on
    a.alert_robot_code = f.robot_code
where
    b.deleted = 0
    and c.deleted = 0
    and a.status <![CDATA[ < ]]> 2
<if test="dto.taskId != null and dto.taskId != ''">
  and a.task_id = #{dto.taskId}
</if>
<if test="dto.taskName != null and dto.taskName != ''">
  and a.task_name like '%' || #{dto.taskName} || '%'
</if>
<if test="dto.status != null">
  and a.status = #{dto.status}
</if>
<if test="dto.appId != null and dto.appId != ''">
  and a.app_id = #{dto.appId}
</if>
<if test="dto.robotCode != null and dto.robotCode != ''">
  and a.robot_code = #{dto.robotCode}
</if>
<if test="dto.robotName != null and dto.robotName != ''">
  and c.robot_name like '%' || #{dto.robotName} || '%'
</if>
<if test="dto.conversationType != null">
  and a.conversation_type = #{dto.conversationType}
</if>
<if test="dto.openConversationId != null and dto.openConversationId != ''">
  and a.open_conversation_id = #{dto.openConversationId}
</if>
<if test="dto.phones != null and dto.phones != ''">
  and a.phones like '%' || #{dto.phones} || '%'
</if>
<if test="dto.userIds != null and dto.userIds != ''">
  and a.user_ids like '%' || #{dto.userIds} || '%'
</if>
<if test="dto.sftpId != null and dto.sftpId != ''">
  and a.sftp_id = #{dto.sftpId}
</if>
<if test="dto.host != null and dto.host != ''">
  and d.host like '%' || #{dto.host} || '%'
</if>
)
select * from t101
</script>
""")
    List<AppTaskBo> listAppTask(Page<AppTaskBo> page, @Param("dto") ListAppTaskDto dto);

    /**
     * 根据id查询应用任务
     * @param taskId 任务id
     */
    @Select("""
select
    a.*,
    b.app_name,
    c.robot_name,
    c.robot_secret,
    d.host,
    d.port,
    d.username,
    d."password",
    f.robot_secret as alert_robot_secret
from
    dingtalk.app_task a
join dingtalk.app b on
    a.app_id = b.app_id
join dingtalk.robot c on
    a.robot_code = c.robot_code
join dingtalk.app_sftp d on
    a.sftp_id = d.sftp_id
    and a.app_id = d.app_id
join dingtalk.app_robot e on
    a.app_id = e.app_id
    and a.robot_code = e.robot_code
left join dingtalk.robot f on
    a.alert_robot_code = f.robot_code
where
    b.deleted = 0
    and c.deleted = 0
    and a.task_id = #{taskId}
""")
    AppTaskBo getAppTaskByTaskId(@Param("taskId") String taskId);
}
