package com.nokia.dingtalk_api.pojos.dto.cms;

import com.nokia.dingtalk_api.annotation.ValidCron;
import com.nokia.dingtalk_api.annotation.ValidRegex;
import com.nokia.dingtalk_api.pojos.enums.FileMethodEnum;
import com.nokia.dingtalk_api.pojos.enums.SubdirectoryMethodEnum;
import com.nokia.dingtalk_api.pojos.enums.TaskAlertTypeEnum;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;

@Data
public class AddAppTaskDto {
    @Schema(description = "应用编码")
    @NotBlank
    private String appId;
    @Schema(description = "任务名称")
    @NotBlank
    private String taskName;
    @Schema(description = "任务描述")
    private String description;
    @Schema(description = "cron表达式")
    @ValidCron
    private String cron;
    @Schema(description = "机器人编码")
    @NotBlank
    private String robotCode;
    @Schema(description = "会话类型：1：单聊，2：群聊")
    @Min(value = 1)
    @Max(value = 2)
    @NotNull
    private Integer conversationType;
    @Schema(description = "群id")
    private String openConversationId;
    @Schema(description = "接收机器人消息的用户的手机号列表")
    private String phones;
    @Schema(description = "接收机器人消息的用户的userId列表")
    private String userIds;
    @Schema(description = "sftp id")
    @NotBlank
    private String sftpId;
    @Schema(description = "数据主文件夹")
    @NotBlank
    private String masterDir;
    @Schema(description = "是否有子文件夹，0否1是")
    @Min(value = 0)
    @Max(value = 1)
    @NotNull
    private Integer hasSubdirectory;
    @Schema(description = "子文件夹匹配方式")
    private SubdirectoryMethodEnum subdirectoryMethod;
    @Schema(description = "子文件夹时延")
    private Integer dirTimeDelay;
    @Schema(description = "匹配最新子文件夹正则表达式")
    @ValidRegex
    private String subdirectoryPattern;
    @Schema(description = "文件是否转为文本，0否1是")
    @Min(value = 0)
    @Max(value = 1)
    @NotNull
    private Integer fileToText;
    @Schema(description = "文件匹配方式")
    @NotNull
    private FileMethodEnum fileMethod;
    @Schema(description = "文件时延")
    private Integer fileTimeDelay;
    @Schema(description = "文件前缀")
    private String filePrefix;
    @Schema(description = "文件扩展名")
    private String fileExtension;
    @Schema(description = "文件名匹配正则表达式")
    @ValidRegex
    private String filePattern;
    @Schema(description = "任务超时时间秒")
    @NotNull
    private Integer taskTimeout;
    @Schema(description = "最大失败重试次数")
    @Min(value = 0)
    @NotNull
    private Integer maxRetryTimes;
    @Schema(description = "重试间隔秒")
    @Min(value = 0)
    @NotNull
    private Integer retryInterval;
    @Schema(description = "告警方式")
    @NotNull
    private TaskAlertTypeEnum alertType;
    @Schema(description = "告警机器人编码")
    private String alertRobotCode;
    @Schema(description = "告警群id")
    private String alertOpenConversationId;
    @Schema(description = "接收告警的手机号列表")
    private String alertPhones;
    @Schema(description = "接收告警的用户的userId列表")
    private String alertUserIds;
}
