package com.nokia.dingtalk_api.pojos.po;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.nokia.dingtalk_api.common.exception.MyRuntimeException;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ResetAppSecretDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppDto;
import com.nokia.dingtalk_api.util.AesUtil;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.security.NoSuchAlgorithmException;
import java.time.LocalDateTime;

/**
 * <p>
 * 应用
 * </p>
 *
 */
@AllArgsConstructor
@NoArgsConstructor
@Data
@TableName("dingtalk.app")
public class AppPo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 应用编码
     */
    @TableId
    private String appId;

    /**
     * 应用密钥
     */
    private String appSecret;

    /**
     * 应用名称
     */
    private String appName;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 是否删除，0否1是
     */
    private Integer deleted;

    public AppPo(AddAppDto dto) {
        LocalDateTime now = LocalDateTime.now();
        this.appId = dto.getAppId();
        try {
            this.appSecret = AesUtil.generateKey();
        } catch (NoSuchAlgorithmException e) {
            throw new MyRuntimeException(e);
        }
        this.appName = dto.getAppName();
        this.createTime = now;
        this.updateTime = now;
        this.deleted = 0;
    }

    public AppPo(UpdateAppDto dto) {
        this.appId = dto.getAppId();
        this.updateTime = LocalDateTime.now();
        this.appName = dto.getAppName();
    }

    public AppPo(ResetAppSecretDto dto) {
        this.appId = dto.getAppId();
        try {
            this.appSecret = AesUtil.generateKey();
            this.updateTime = LocalDateTime.now();
        } catch (NoSuchAlgorithmException e) {
            throw new MyRuntimeException(e);
        }
    }

    public AppPo(DeleteAppDto dto) {
        this.appId = dto.getAppId();
        this.deleted = 1;
        this.updateTime = LocalDateTime.now();
    }
}
