package com.nokia.dingtalk_api.pojos.po;

import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.nokia.dingtalk_api.pojos.bo.AppTaskBo;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 应用定时任务日志
 * </p>
 *
 */
@AllArgsConstructor
@NoArgsConstructor
@Data
@TableName("dingtalk.app_task_log")
public class AppTaskLogPo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 日志id
     */
    @Schema(description = "日志id")
    @TableId
    private String id;

    /**
     * 任务id
     */
    @Schema(description = "任务id")
    private String taskId;

    /**
     * 任务名称
     */
    @Schema(description = "任务名称")
    private String taskName;

    /**
     * 应用编码
     */
    @Schema(description = "应用编码")
    private String appId;

    /**
     * 应用名称
     */
    @Schema(description = "应用名称")
    private String appName;

    /**
     * 机器人编码
     */
    @Schema(description = "机器人编码")
    private String robotCode;

    /**
     * 机器人名称
     */
    @Schema(description = "机器人名称")
    private String robotName;

    /**
     * 会话类型：1：单聊，2：群聊
     */
    @Schema(description = "会话类型：1：单聊，2：群聊")
    private Integer conversationType;

    /**
     * 群id
     */
    @Schema(description = "群id")
    private String openConversationId;

    /**
     * 接收机器人消息的用户的手机号列表
     */
    @Schema(description = "接收机器人消息的用户的手机号列表")
    private String phones;

    /**
     * 接收机器人消息的用户的userId列表
     */
    @Schema(description = "接收机器人消息的用户的userId列表")
    private String userIds;

    /**
     * sftp id
     */
    @Schema(description = "sftp id")
    private String sftpId;

    /**
     * sftp ip
     */
    @Schema(description = "sftp ip")
    private String host;
    /**
     * 端口
     */
    @Schema(description = "sftp端口")
    private Integer port;

    /**
     * 要发送的文件
     */
    @Schema(description = "要发送的文件")
    private String files;

    /**
     * 任务执行状态，0失败1成功
     */
    @Schema(description = "任务执行状态，0失败1成功")
    private Integer status;

    /**
     * 详情
     */
    @Schema(description = "详情")
    private String detail;

    /**
     * 执行时间
     */
    @Schema(description = "执行时间")
    private LocalDateTime createTime;

    /**
     * 消息id列表
     */
    @Schema(description = "消息id列表")
    private String processQueryKeys;

    public AppTaskLogPo(AppTaskBo t) {
        this.id = IdUtil.simpleUUID();
        this.taskId = t.getTaskId();
        this.taskName = t.getTaskName();
        this.appId = t.getAppId();
        this.appName = t.getAppName();
        this.robotCode = t.getRobotCode();
        this.robotName = t.getRobotName();
        this.conversationType = t.getConversationType();
        this.openConversationId = t.getOpenConversationId();
        this.phones = t.getPhones();
        this.userIds = t.getUserIds();
        this.sftpId = t.getSftpId();
        this.host = t.getHost();
        this.port = t.getPort();
        this.status = 1;
        this.createTime = LocalDateTime.now();
    }
}
