package com.nokia.dingtalk_api.pojos.po;

import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppTaskDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppTaskDto;
import com.nokia.dingtalk_api.pojos.enums.AppTaskStatusEnum;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.util.StringUtils;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 应用定时任务
 * </p>
 *
 */
@AllArgsConstructor
@NoArgsConstructor
@Data
@TableName("dingtalk.app_task")
public class AppTaskPo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 任务id
     */
    @TableId
    private String taskId;

    /**
     * 任务名称
     */
    private String taskName;

    /**
     * 任务描述
     */
    private String description;

    /**
     * 任务状态，0已停止1运行中2已删除
     */
    private Integer status;

    /**
     * cron表达式
     */
    private String cron;

    /**
     * 应用编码
     */
    private String appId;

    /**
     * 机器人编码
     */
    private String robotCode;

    /**
     * 会话类型：1：单聊，2：群聊
     */
    private Integer conversationType;

    /**
     * 群id
     */
    private String openConversationId;

    /**
     * 接收机器人消息的用户的手机号列表
     */
    private String phones;

    /**
     * 接收机器人消息的用户的userId列表
     */
    private String userIds;

    /**
     * sftp id
     */
    private String sftpId;

    /**
     * 数据主文件夹
     */
    private String masterDir;

    /**
     * 是否有子文件夹，0否1是
     */
    private Integer hasSubdirectory;

    /**
     * 子文件夹匹配方式
     */
    private String subdirectoryMethod;

    /**
     * 子文件夹时延
     */
    private Integer dirTimeDelay;

    /**
     * 匹配最新子文件夹正则表达式
     */
    private String subdirectoryPattern;

    /**
     * 文件是否转为文本，0否1是
     */
    private Integer fileToText;

    /**
     * 文件匹配方式
     */
    private String fileMethod;

    /**
     * 文件时延
     */
    private Integer fileTimeDelay;

    /**
     * 文件前缀
     */
    private String filePrefix;

    /**
     * 文件扩展名
     */
    private String fileExtension;

    /**
     * 文件匹配正则表达式
     */
    private String filePattern;

    /**
     * 任务超时时间秒
     */
    private Integer taskTimeout;

    /**
     * 最大失败重试次数
     */
    private Integer maxRetryTimes;

    /**
     * 重试间隔秒
     */
    private Integer retryInterval;

    /**
     * 告警方式
     */
    private String alertType;

    /**
     * 告警机器人编码
     */
    private String alertRobotCode;

    /**
     * 告警群id
     */
    private String alertOpenConversationId;

    /**
     * 接收告警的手机号列表
     */
    private String alertPhones;

    /**
     * 接收告警的用户的userId列表
     */
    private String alertUserIds;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    public AppTaskPo(AddAppTaskDto dto) {
        LocalDateTime now = LocalDateTime.now();
        this.taskId = IdUtil.simpleUUID();
        this.taskName = dto.getTaskName();
        this.description = dto.getDescription();
        this.status = StringUtils.hasText(dto.getCron()) ? AppTaskStatusEnum.RUNNING.value
                : AppTaskStatusEnum.STOPPED.value;
        this.cron = StringUtils.hasText(dto.getCron()) ? dto.getCron() : "";
        this.appId = dto.getAppId();
        this.robotCode = dto.getRobotCode();
        this.conversationType = dto.getConversationType();
        this.openConversationId = dto.getOpenConversationId();
        this.phones = dto.getPhones();
        this.userIds = dto.getUserIds();
        this.sftpId = dto.getSftpId();
        this.masterDir = dto.getMasterDir();
        this.hasSubdirectory = dto.getHasSubdirectory();
        this.subdirectoryMethod = dto.getSubdirectoryMethod() == null ? "" : dto.getSubdirectoryMethod().name();
        this.dirTimeDelay = dto.getDirTimeDelay();
        this.subdirectoryPattern = dto.getSubdirectoryPattern();
        this.fileToText = dto.getFileToText();
        this.fileMethod = dto.getFileMethod().name();
        this.fileTimeDelay = dto.getFileTimeDelay();
        this.filePrefix = dto.getFilePrefix();
        this.fileExtension = dto.getFileExtension();
        this.filePattern = dto.getFilePattern();
        this.taskTimeout = dto.getTaskTimeout();
        this.maxRetryTimes = dto.getMaxRetryTimes();
        this.retryInterval = dto.getRetryInterval();
        this.alertType = dto.getAlertType() == null ? "" : dto.getAlertType().name();
        this.alertRobotCode = dto.getAlertRobotCode();
        this.alertOpenConversationId = dto.getAlertOpenConversationId();
        this.alertPhones = dto.getAlertPhones();
        this.alertUserIds = dto.getAlertUserIds();
        this.createTime = now;
        this.updateTime = now;
    }

    public AppTaskPo(UpdateAppTaskDto dto) {
        LocalDateTime now = LocalDateTime.now();
        this.taskId = dto.getTaskId();
        this.taskName = dto.getTaskName();
        this.description = dto.getDescription();
        this.cron = StringUtils.hasText(dto.getCron()) ? dto.getCron() : "";
        this.appId = dto.getAppId();
        this.robotCode = dto.getRobotCode();
        this.conversationType = dto.getConversationType();
        this.openConversationId = dto.getOpenConversationId();
        this.phones = dto.getPhones();
        this.userIds = dto.getUserIds();
        this.sftpId = dto.getSftpId();
        this.masterDir = dto.getMasterDir();
        this.hasSubdirectory = dto.getHasSubdirectory();
        this.subdirectoryMethod = dto.getSubdirectoryMethod() == null ? "" : dto.getSubdirectoryMethod().name();
        this.dirTimeDelay = dto.getDirTimeDelay();
        this.subdirectoryPattern = dto.getSubdirectoryPattern();
        this.fileToText = dto.getFileToText();
        this.fileMethod = dto.getFileMethod().name();
        this.fileTimeDelay = dto.getFileTimeDelay();
        this.filePrefix = dto.getFilePrefix();
        this.fileExtension = dto.getFileExtension();
        this.filePattern = dto.getFilePattern();
        this.taskTimeout = dto.getTaskTimeout();
        this.maxRetryTimes = dto.getMaxRetryTimes();
        this.retryInterval = dto.getRetryInterval();
        this.alertType = dto.getAlertType() == null ? "" : dto.getAlertType().name();
        this.alertRobotCode = dto.getAlertRobotCode();
        this.alertOpenConversationId = dto.getAlertOpenConversationId();
        this.alertPhones = dto.getAlertPhones();
        this.alertUserIds = dto.getAlertUserIds();
        this.updateTime = now;
    }
}
