package com.nokia.dingtalk_api.pojos.po;

import com.aliyun.dingtalkrobot_1_0.models.BatchSendOTOResponse;
import com.aliyun.dingtalkrobot_1_0.models.OrgGroupSendResponse;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.nokia.dingtalk_api.common.exception.MyRuntimeException;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 钉钉发送消息日志
 * </p>
 *
 */
@AllArgsConstructor
@NoArgsConstructor
@Data
@TableName("dingtalk.send_message_log")
public class SendMessageLogPo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 发送时间
     */
    private LocalDateTime sendTime;

    /**
     * 消息id
     */
    @TableId
    private String processQueryKey;

    /**
     * 发送机器人编码
     */
    private String robotCode;

    /**
     * 告警机器人编码
     */
    private String alertRobotCode;

    /**
     * 会话类型：1：单聊，2：群聊
     */
    private Integer conversationType;

    /**
     * 群id
     */
    private String openConversationId;

    /**
     * 接收机器人消息的用户的userId列表
     */
    private String userIds;

    /**
     * 内容
     */
    private String content;

    /**
     * 接口响应
     */
    private String response;

    public SendMessageLogPo(String robotCode, String alertRobotCode, String openConversationId, String content,
                            OrgGroupSendResponse response) {
        this.sendTime = LocalDateTime.now();
        this.processQueryKey = response.body.processQueryKey;
        this.robotCode = robotCode;
        this.alertRobotCode = alertRobotCode;
        this.conversationType = 2;
        this.openConversationId = openConversationId;
        this.content = content;
        try {
            this.response = new ObjectMapper().writeValueAsString(response);
        } catch (JsonProcessingException e) {
            throw new MyRuntimeException(e);
        }
    }

    public SendMessageLogPo(String robotCode, String openConversationId, String content, OrgGroupSendResponse response) {
        this(robotCode, null, openConversationId, content, response);
    }

    public SendMessageLogPo(String robotCode, String alertRobotCode, List<String> userIds, String content,
                            BatchSendOTOResponse response) {
        this.sendTime = LocalDateTime.now();
        this.processQueryKey = response.body.processQueryKey;
        this.robotCode = robotCode;
        this.alertRobotCode = alertRobotCode;
        this.conversationType = 1;
        this.userIds = userIds.toString();
        this.content = content;
        try {
            this.response = new ObjectMapper().writeValueAsString(response);
        } catch (JsonProcessingException e) {
            throw new MyRuntimeException(e);
        }
    }

    public SendMessageLogPo(String robotCode, List<String> userIds, String content,
                            BatchSendOTOResponse response) {
        this(robotCode, null, userIds, content, response);
    }
}
