package com.nokia.dingtalk_api.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.nokia.dingtalk_api.common.R;
import com.nokia.dingtalk_api.dao.IRobotCommandService;
import com.nokia.dingtalk_api.pojos.dto.cms.AddAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.DeleteAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.ListAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.dto.cms.UpdateAppRobotCommandDto;
import com.nokia.dingtalk_api.pojos.enums.SortEnum;
import com.nokia.dingtalk_api.pojos.po.RobotCommandPo;
import com.nokia.dingtalk_api.pojos.vo.PageVo;
import com.nokia.dingtalk_api.pojos.vo.cms.ListAppRobotCommandVo;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class AppRobotCommandService {
    private final IRobotCommandService iRobotCommandService;

    public R<PageVo<ListAppRobotCommandVo>> listAppRobotCommand(ListAppRobotCommandDto dto) {
        QueryWrapper<RobotCommandPo> wrapper = new QueryWrapper<>();
        wrapper.eq("app_id", dto.getAppId());
        wrapper.eq("robot_code", dto.getRobotCode());
        if (StringUtils.hasText(dto.getCommand())) {
            wrapper.like("command", "%" + dto.getCommand() + "%");
        }
        Page<RobotCommandPo> page = new Page<>(dto.getCurrent(), dto.getPageSize());
        if (CollectionUtils.isEmpty(dto.getSort())) {
            page.addOrder(OrderItem.asc("command"));
        } else {
            List<OrderItem> items = dto.getSort().entrySet().stream()
                    .map(t -> t.getValue().equals(SortEnum.ascend) ? OrderItem.asc(t.getKey().value)
                            : OrderItem.desc(t.getKey().value)).toList();
            page.addOrder(items);
        }
        List<RobotCommandPo> list = iRobotCommandService.list(page, wrapper);
        List<ListAppRobotCommandVo> vos = list.stream().map(ListAppRobotCommandVo::new).toList();
        return R.ok(new PageVo<>(page.getTotal(), vos));
    }

    @Transactional(rollbackFor = Exception.class)
    public R<Object> addAppRobotCommand(AddAppRobotCommandDto dto) {
        QueryWrapper<RobotCommandPo> wrapper = new QueryWrapper<>();
        wrapper.eq("app_id", dto.getAppId());
        wrapper.eq("robot_code", dto.getRobotCode());
        wrapper.eq("command", dto.getCommand());
        boolean exists = iRobotCommandService.exists(wrapper);
        if (exists) {
            return R.error("命令已存在");
        }
        RobotCommandPo po = new RobotCommandPo(dto);
        iRobotCommandService.save(po);
        return R.ok();
    }

    @Transactional(rollbackFor = Exception.class)
    public R<Object> updateAppRobotCommand(UpdateAppRobotCommandDto dto) {
        UpdateWrapper<RobotCommandPo> wrapper = new UpdateWrapper<>();
        wrapper.eq("app_id", dto.getAppId());
        wrapper.eq("robot_code", dto.getRobotCode());
        wrapper.eq("command", dto.getCommand());
        RobotCommandPo po = new RobotCommandPo(dto);
        iRobotCommandService.update(po, wrapper);
        return R.ok();
    }

    @Transactional(rollbackFor = Exception.class)
    public R<Object> deleteAppRobotCommand(DeleteAppRobotCommandDto dto) {
        UpdateWrapper<RobotCommandPo> wrapper = new UpdateWrapper<>();
        wrapper.eq("app_id", dto.getAppId());
        wrapper.eq("robot_code", dto.getRobotCode());
        wrapper.eq("command", dto.getCommand());
        iRobotCommandService.remove(wrapper);
        return R.ok();
    }
}
