package com.nokia.dingtalk_api.service;

import com.aliyun.dingtalkoauth2_1_0.models.GetAccessTokenResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dingtalk.open.app.api.OpenDingTalkClient;
import com.dingtalk.open.app.api.OpenDingTalkStreamClientBuilder;
import com.dingtalk.open.app.api.security.AuthClientCredential;
import com.nokia.dingtalk_api.dao.IRobotService;
import com.nokia.dingtalk_api.pojos.enums.RedisPrefixEnum;
import com.nokia.dingtalk_api.pojos.po.RobotPo;
import com.nokia.dingtalk_api.util.DingTalkApiUtil;
import jakarta.annotation.PostConstruct;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

@Slf4j
@Service
@RequiredArgsConstructor
public class DingtalkClientService {
    static final String TOPIC = "/v1.0/im/bot/messages/get";
    static final ConcurrentMap<String, OpenDingTalkClient> MAP = new ConcurrentHashMap<>();
    private final RobotCallbackService robotCallbackService;
    private final AesService aesService;
    private final IRobotService iRobotService;
    private final RedisTemplate<String, Object> redisTemplate;

    /**
     * 移除钉钉机器人客户端
     * @param key 机器人编码
     */
    public void remove(String key) {
        OpenDingTalkClient client = MAP.get(key);
        if (client == null) {
            return;
        }
        MAP.remove(key);
        try {
            client.stop();
        } catch (Exception e) {
            log.error(e.toString(), e);
        }
    }

    /**
     * 更新钉钉机器人客户端
     * @param po 机器人信息
     */
    public void update(RobotPo po) {
        String robotSecret = aesService.decrypt(po.getRobotSecret());
        // 测试机器人是否可用
        GetAccessTokenResponse r = DingTalkApiUtil.getAccessToken(po.getRobotCode(), robotSecret);
        redisTemplate.opsForValue().set(RedisPrefixEnum.DINGTALK_ACCESS_TOKEN.prefix + po.getRobotCode(),
                r.body, r.body.expireIn - 60, RedisPrefixEnum.DINGTALK_ACCESS_TOKEN.timeUnit);
        OpenDingTalkClient clientOld = MAP.get(po.getRobotCode());
        if (clientOld != null) {
            MAP.remove(po.getRobotCode());
            try {
                clientOld.stop();
            } catch (Exception e) {
                log.error(e.toString(), e);
            }
        }
        OpenDingTalkClient clientNew = OpenDingTalkStreamClientBuilder
                .custom()
                .credential(new AuthClientCredential(po.getRobotCode(), robotSecret))
                .registerCallbackListener(TOPIC, robotCallbackService)
                .build();
        try {
            clientNew.start();
            MAP.put(po.getRobotCode(), clientNew);
        } catch (Exception e) {
            log.error(e.toString(), e);
        }
    }

    /**
     * 钉钉机器人客户端初始化
     */
    @PostConstruct
    public void init() {
        QueryWrapper<RobotPo> wrapper = new QueryWrapper<>();
        wrapper.eq("deleted", 0);
        List<RobotPo> list = iRobotService.list(wrapper);
        list.forEach(t -> {
            try {
                update(t);
            } catch (Exception e) {
                log.error(e.toString(), e);
            }
        });
        log.info("DingtalkClient init: {}", MAP);
    }
}
