package com.nokia.dingtalk_api.service;

import com.nokia.dingtalk_api.dao.IRequestLogService;
import com.nokia.dingtalk_api.pojos.po.RequestLogPo;
import jakarta.annotation.PostConstruct;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.TimeUnit;

@RequiredArgsConstructor
@Slf4j
@Service
public class RequestLogService {
    public static final ConcurrentLinkedQueue<RequestLogPo> QUEUE = new ConcurrentLinkedQueue<>();
    private final IRequestLogService iRequestLogService;

    public void offer(RequestLogPo requestLog) {
        QUEUE.offer(requestLog);
    }

    /**
     * 消费请求日志队列保存数据库
     */
    @PostConstruct
    public void consumer() {
        CompletableFuture.runAsync(() -> {
            while (true) {
                try {
                    RequestLogPo requestLogPo = QUEUE.poll();
                    if (requestLogPo != null) {
                        iRequestLogService.save(requestLogPo);
                    } else {
                        TimeUnit.SECONDS.sleep(1);
                    }
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                }
            }
        });
    }
}
