package com.nokia.dingtalk_api.util;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;

import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.KeyGenerator;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Base64;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ThreadLocalRandom;

/**
 * 加密解密工具
 */
@Slf4j
public class AesUtil {
    /**
     * 加密算法
     */
    private static final String ALGORITHM = "AES";
    /**
     * 加密算法填充方式
     */
    private static final String TRANSFORMATION = ALGORITHM + "/ECB/PKCS5Padding";

    public static void main(String[] args) {
        try {
            // 应用编码
            String appId = "";
            // 应用密钥
            String appSecret = "";
            // 生成token
            String token = generateToken(appId, appSecret);
            System.out.println(token);
        } catch (Exception e) {
            log.error(e.toString(), e);
        }
    }

    /**
     * 加密
     * @param text 内容
     * @param key 密钥
     */
    public static String encrypt(String text, String key) throws NoSuchPaddingException, NoSuchAlgorithmException,
            IllegalBlockSizeException, BadPaddingException, InvalidKeyException {
        Cipher cipher = Cipher.getInstance(TRANSFORMATION);
        cipher.init(Cipher.ENCRYPT_MODE, new SecretKeySpec(Base64.getDecoder().decode(key), ALGORITHM));
        return Base64.getEncoder().encodeToString(cipher.doFinal(text.getBytes()));
    }

    /**
     * 解密
     * @param text 加密内容
     * @param key 密钥
     */
    public static String decrypt(String text, String key) throws NoSuchPaddingException, NoSuchAlgorithmException,
            InvalidKeyException, IllegalBlockSizeException, BadPaddingException {
        Cipher cipher = Cipher.getInstance(TRANSFORMATION);
        cipher.init(Cipher.DECRYPT_MODE, new SecretKeySpec(Base64.getDecoder().decode(key), ALGORITHM));
        return new String(cipher.doFinal(Base64.getDecoder().decode(text)));
    }

    /**
     * 生成密钥
     */
    public static String generateKey() throws NoSuchAlgorithmException {
        KeyGenerator keyGen = KeyGenerator.getInstance(ALGORITHM);
        keyGen.init(128);
        SecretKey secretKey = keyGen.generateKey();
        return Base64.getEncoder().encodeToString(secretKey.getEncoded());
    }

    /**
     * 生成token
     * @param appId 应用编码
     * @param appSecret 应用密钥
     */
    public static String generateToken(String appId, String appSecret) throws JsonProcessingException,
            NoSuchPaddingException, IllegalBlockSizeException, NoSuchAlgorithmException, BadPaddingException,
            InvalidKeyException {
        // 获取当前时间
        LocalDateTime now = LocalDateTime.now();
        // 格式化时间戳
        String timestamp = now.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSS"));
        // 生成追踪ID
        String traceId = generateTraceId(now);
        // 创建对象映射器用于处理JSON
        ObjectMapper objectMapper = new ObjectMapper();
        // 创建Map存储需要加密的信息
        Map<String, String> m = new HashMap<>();
        m.put("APP_ID", appId);
        m.put("TIMESTAMP", timestamp);
        m.put("TRACE_ID", traceId);
        // 将Map转换为JSON字符串并进行加密
        String s = objectMapper.writeValueAsString(m);
        return encrypt(s, appSecret);
    }

    /**
     * 生成traceId
     * @param time 时间
     */
    public static String generateTraceId(LocalDateTime time) {
        return time.format(DateTimeFormatter.ofPattern("yyyyMMddHHmmssSSS"))
                + ThreadLocalRandom.current().nextInt(100000, 1000000);
    }

    /**
     * 生成traceId
     */
    public static String generateTraceId() {
        return generateTraceId(LocalDateTime.now());
    }
}
