package com.nokia.dingtalk_api.util;

import com.dingtalk.api.DefaultDingTalkClient;
import com.dingtalk.api.DingTalkClient;
import com.dingtalk.api.request.OapiRobotSendRequest;
import com.dingtalk.api.response.OapiRobotSendResponse;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 机器人发送消息webhook工具
 * @link <a href="https://open.dingtalk.com/document/orgapp/custom-bot-send-message-type">...</a>
 */
@Slf4j
public class DingtalkWebhookUtil {
    /**
     * 发送文本类型消息
     * @param webhook 机器人 Webhook 地址
     * @param content 消息内容
     * @param atAll 是否@所有人
     * @param atMobiles 被@人的手机号
     * @param atUserIds 被@人的用户userId
     */
    public static OapiRobotSendResponse groupSendText(String webhook, String content, Boolean atAll,
                                                      List<String> atMobiles, List<String> atUserIds) throws Exception {
        ObjectMapper objectMapper = new ObjectMapper();
        DingTalkClient client = new DefaultDingTalkClient(webhook);
        OapiRobotSendRequest request = new OapiRobotSendRequest();
        request.setMsgtype("text");
        OapiRobotSendRequest.Text text = new OapiRobotSendRequest.Text();
        text.setContent(content);
        request.setText(text);
        OapiRobotSendRequest.At at = new OapiRobotSendRequest.At();
        at.setIsAtAll(atAll);
        at.setAtMobiles(atMobiles);
        at.setAtUserIds(atUserIds);
        request.setAt(at);
        OapiRobotSendResponse response = client.execute(request);
        log.info("OapiRobotSendResponse: {}", objectMapper.writeValueAsString(response));
        return response;
    }

    /**
     * 发送markdown类型消息
     * @param webhook 机器人 Webhook 地址
     * @param title 首屏会话透出的展示内容
     * @param text markdown格式的消息
     * @param atAll 是否@所有人
     * @param atMobiles 被@人的手机号
     * @param atUserIds 被@人的用户userId
     */
    public static OapiRobotSendResponse groupSendMarkdown(String webhook, String title, String text, Boolean atAll,
                                                          List<String> atMobiles, List<String> atUserIds)
            throws Exception {
        ObjectMapper objectMapper = new ObjectMapper();
        DingTalkClient client = new DefaultDingTalkClient(webhook);
        OapiRobotSendRequest request = new OapiRobotSendRequest();
        request.setMsgtype("markdown");
        OapiRobotSendRequest.Markdown markdown = new OapiRobotSendRequest.Markdown();
        markdown.setTitle(title);
        markdown.setText(text);
        request.setMarkdown(markdown);
        OapiRobotSendRequest.At at = new OapiRobotSendRequest.At();
        at.setIsAtAll(atAll);
        at.setAtMobiles(atMobiles);
        at.setAtUserIds(atUserIds);
        request.setAt(at);
        OapiRobotSendResponse response = client.execute(request);
        log.info("OapiRobotSendResponse: {}", objectMapper.writeValueAsString(response));
        return response;
    }
}
